fraction

package
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 4, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package fraction provides options for fraction field rendering in clog.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Fraction

type Fraction = core.Fraction

Fraction is the value type for fraction fields.

type Option

type Option func(*Fraction)

Option configures how a fraction field is rendered.

func WithReverseGradient

func WithReverseGradient() Option

WithReverseGradient returns an Option that flips the gradient direction for this field relative to the logger default.

Jump to