printer

package
v0.11.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EmitStyled added in v0.8.2

func EmitStyled(buf *strings.Builder, text string, style *lipgloss.Style)

EmitStyled writes text to buf, applying style if non-nil. Only the visible content is styled; surrounding whitespace is emitted verbatim to avoid lipgloss padding shorter lines to match the widest line.

Types

This section is empty.

Directories

Path Synopsis
Package hcl provides HCL syntax highlighting for clog.
Package hcl provides HCL syntax highlighting for clog.
Package json provides JSON syntax highlighting for clog.
Package json provides JSON syntax highlighting for clog.
Package toml provides TOML syntax highlighting for clog.
Package toml provides TOML syntax highlighting for clog.
Package yaml provides YAML syntax highlighting for clog.
Package yaml provides YAML syntax highlighting for clog.

Jump to