package
Version:
v0.8.1
Opens a new window with list of versions in this module.
Published: Apr 4, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package fraction provides options for fraction field rendering in clog.
Fraction is the value type for fraction fields.
Option configures how a fraction field is rendered.
func WithReverseGradient() Option
WithReverseGradient returns an Option that flips the gradient
direction for this field relative to the logger default.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.